@@ -31,7 +31,7 @@ def pytest_runtest_makereport(item, call):
 @pytest.fixture
 def test_obj(base_url, browser, browser_version, os_version, os_name, remote_flag, testrail_flag, tesults_flag,
              test_run_id, remote_project_name, remote_build_name, testname, reportportal_service, interactivemode_flag,
-             test_env, screenshot_option, xlsx_config, product, non_breakable):
+             test_env, screenshot_option, xlsx_config, product, non_breakable, capture):
     "Return an instance of Base Page that knows about the third party integrations"
     try:
 
@@ -41,7 +41,7 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         #     if default_flag == False:
         #         browser, browser_version, remote_flag, os_name, os_version, testrail_flag, tesults_flag = interactive_mode.ask_questions_gui(
         #             browser, browser_version, os_version, os_name, remote_flag, testrail_flag, tesults_flag)
-        test_obj = Zero_Page(base_url="http://", product=product_list.QCare)
+        test_obj = Zero_Page(base_url="http://", product=product)
         test_obj.test_env = test_env
         test_obj.non_breakable = non_breakable
         test_obj.screenshot = screenshot_option
@@ -52,6 +52,7 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         # Setup and register a driver
         test_obj.register_driver(remote_flag, os_name, os_version, browser, browser_version, remote_project_name,
                                  remote_build_name)
+        test_obj.capture = capture
 
         # Setup TestRail reporting
         # if testrail_flag.lower() == 'y':
@@ -200,9 +201,23 @@ def non_breakable(request):
 
 @pytest.fixture
 def cases(request, product, testID):
+
     name = request.config.getoption("--xlsx")
     sheet = "Context"
-    df = pd.read_excel("././conf/web/" + product + '/' + name, sheet_name=sheet, dtype=str,
+    xlsx_path_app = "././conf/app/" + product + '/' + name
+    xlsx_path_web = "././conf/web/" + product + '/' + name
+    xlsx_path_rwd = "././conf/rwd" + product + '/' + name
+
+    if os.path.exists(xlsx_path_app):
+        file_path = xlsx_path_app
+    elif os.path.exists(xlsx_path_web):
+        file_path = xlsx_path_web
+    elif os.path.exists(xlsx_path_rwd):
+        file_path = xlsx_path_rwd
+    else:
+        raise ValueError("File not found in either ././conf/app or ././conf/web directories.")
+
+    df = pd.read_excel(file_path, sheet_name=sheet, dtype=str,
                        usecols=lambda x: 'Remark' not in x)
     df = df.fillna('')
     row = df.index[df['testID'] == testID].tolist()
@@ -817,6 +832,15 @@ def ud_id(request):
         print("Exception when trying to run test: %s" % __file__)
         print("Python says:%s" % str(e))
 
+@pytest.fixture
+def capture(request):
+    try:
+        return request.config.getoption("--capture")
+
+    except Exception as e:
+        print("Exception when trying to run test: %s" % __file__)
+        print("Python says:%s" % str(e))
+
 
 @pytest.fixture
 def org_id(request):
