@@ -11,8 +11,6 @@ import unittest, time, logging, os, inspect
 from ..utils.general.Base_Logging import Base_Logging
 from ..remoteTest.BrowserStack_Library import BrowserStack_Library
 from ..drivers.driverfactory import DriverFactory
-from jinja2 import Template
-import base64
 # from utils.Test_Rail import Test_Rail
 # from utils import Tesults
 from ..utils.general.stop_test_exception_util import Stop_Test_Exception
@@ -149,7 +147,6 @@ class Base_Page(Borg, unittest.TestCase):
             self.window_structure = {}
             self.testrail_flag = False
             self.tesults_flag = False
-            self.base64_flag = True
             self.images = []
             self.browserstack_flag = False
             self.highlight_flag = False
@@ -397,27 +394,7 @@ class Base_Page(Borg, unittest.TestCase):
             self.append_latest_image(screenshot_name)
         if self.tesults_flag is True:
             self.images.append(screenshot_name)
-        if self.base64_flag is True:
-            with open(screenshot_name, "rb") as image_file:
-                encoded_string = base64.b64encode(image_file.read()).decode('utf-8')
-                self.images.append("data:image/png;base64," + encoded_string)
 
-        # Add screenshot to HTML
-        # using Jinja2
-        with open('report.html', 'w') as file:
-            template = Template('''
-                    <html>
-                    <head>
-                        <title>Test Report</title>
-                    </head>
-                    <body>
-                        {% for image in images %}
-                        <img src="{{ image }}" alt="screenshot">
-                        {% endfor %}
-                    </body>
-                    </html>
-                    ''')
-            file.write(template.render(images=self.images))
 
     def open(self, url, wait_time=2):
         "Visit the page base_url + url"
