@@ -98,8 +98,8 @@ class Mobile_Base_Page(Borg, unittest.TestCase):
         self.appium_service = AppiumService()
         # self.appium_service.start(args=['--address', ip, '-p', port])
         self.appium_service.start()
-        self.set_screenshot_dir()  # Create screenshot directory
-        self.set_log_file()
+        # self.set_screenshot_dir()  # Create screenshot directory
+        # self.set_log_file()
         self.write('Start Appium server with url: %s:%s' % (self.appium_service._parse_host(self.appium_service._cmd), self.appium_service._parse_port(self.appium_service._cmd)))
 
     def register_driver(self, mobile_os_name, mobile_os_version, device_name, app_package, app_activity, remote_flag,
@@ -108,8 +108,8 @@ class Mobile_Base_Page(Borg, unittest.TestCase):
         self.driver = self.driver_obj.run_mobile(mobile_os_name, mobile_os_version, device_name, app_package,
                                                  app_activity, remote_flag, device_flag, app_name, app_path, ud_id,
                                                  org_id, signing_id, no_reset_flag, appium_version)
-        # self.set_screenshot_dir()  # Create screenshot directory  # Move to start_appium
-        # self.set_log_file()   # Move to start_appium
+        self.set_screenshot_dir()  # Create screenshot directory  # Move to start_appium
+        self.set_log_file()   # Move to start_appium
         self.start()
 
     def get_current_driver(self):
@@ -138,6 +138,10 @@ class Mobile_Base_Page(Borg, unittest.TestCase):
         "Register Tesults with Page"
         self.tesults_flag = True
 
+    def set_calling_module(self, name):
+        "Set the test name"
+        self.calling_module = name
+
     # def register_browserstack(self):
     #     "Register Browser Stack with Page"
     #     self.browserstack_flag = True
